package tech.mercantec.easyeat

import android.graphics.Color
import android.os.Bundle
import android.view.View
import android.view.ViewGroup
import android.widget.ArrayAdapter
import android.widget.BaseAdapter
import android.widget.ListView
import android.widget.TextView
import android.widget.Toast
import com.google.android.material.bottomnavigation.BottomNavigationView
import androidx.appcompat.app.AppCompatActivity
import androidx.navigation.findNavController
import androidx.navigation.ui.AppBarConfiguration
import androidx.navigation.ui.setupActionBarWithNavController
import androidx.navigation.ui.setupWithNavController
import tech.mercantec.easyeat.databinding.ActivityMainBinding
import tech.mercantec.easyeat.ui.home.DishAdapter
import tech.mercantec.easyeat.ui.home.models.Dish

class MainActivity : AppCompatActivity() {

    private lateinit var binding: ActivityMainBinding

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        binding = ActivityMainBinding.inflate(layoutInflater)
        setContentView(binding.root)

        val navView: BottomNavigationView = binding.navView

        val navController = findNavController(R.id.nav_host_fragment_activity_main)
        val appBarConfiguration = AppBarConfiguration(
            setOf(
                R.id.navigation_home, R.id.navigation_dashboard, R.id.navigation_notifications
            )
        )
        setupActionBarWithNavController(navController, appBarConfiguration)
        navView.setupWithNavController(navController)

        val listView: ListView = findViewById(R.id.dishesList)
        val listItems = arrayOf(
            Dish("Spaghetti Bolognese", "Beef", 70.5),
            Dish("Margherita Pizza", "Cheese", 60.0),
            Dish("Chicken Curry", "Chicken", 80.2),
            Dish("Vegetable Stir Fry", "Mixed Vegetables", 50.5),
            Dish("Sushi", "Fish", 100.0),
            Dish("Beef Tacos", "Beef", 60.8),
            Dish("Lentil Soup", "Lentils", 40.5),
            Dish("Pasta Alfredo", "Cream", 60.9),
            Dish("Caesar Salad", "Chicken", 50.8),
            Dish("Falafel Wrap", "Chickpeas", 50.2)
        )

        val listAdapter = DishAdapter(this, listItems)
        listView.adapter = listAdapter

        listView.setOnItemClickListener { parent, view, position, id ->
            val selectedItem = parent.getItemAtPosition(position) as Dish
            Toast.makeText(this, "you selected $selectedItem.name that costs ${selectedItem.expense} kr.", Toast.LENGTH_LONG).show()
        }
    }
}
